==> apeman-task-contrib-mkdir-1.0.1.tgz: package/README.md <==
apeman-task-contrib-mkdir
=======

[![Build Status][my_travis_badge_url]][my_travis_url]
[![Code Climate][my_codeclimate_badge_url]][my_codeclimate_url]
[![Code Coverage][my_codeclimate_coverage_badge_url]][my_codeclimate_url]
[![npm version][my_npm_budge_url]][my_npm_url]

Apeman task contribution plugin to make directories.


Installation
-------
 
```bash
npm install apeman-task-contrib-mkdir --save-dev
```

Usage
-------

Define your a task with worker name `apeman-task-contrib-mkdir` in **Apemanfile.js**

`$params`should be directory names to make.

```javascript
// This is Apemanfile.js example.
module.exports = {
    $package: {/*...*/},
    $tasks: {
        "structure-my-project": {
            "$worker": "apeman-task-contrib-mkdir",
            "$params": [
                "bin",
                "lib",
                "docs",
                "docs/apiguide",
                "test",
                "test/unit_tests"
            ],
        }
    }
}
```

Then, run it from call the task via [apeman CLI].

```bash
apeman task structure-my-project
```

License
-------
This software is released under the [MIT License][my_license_url].


<!-- Links -->
[apeman_url]: https://github.com/apeman-repo/apeman
[my_repo_url]: https://github.com/apeman-repo/apeman-task-contrib-mkdir
[my_travis_url]: http://travis-ci.org/apeman-repo/apeman-task-contrib-mkdir
[my_travis_badge_url]: http://img.shields.io/travis/apeman-repo/apeman-task-contrib-mkdir.svg?style=flat
[my_license_url]: https://github.com/apeman-repo/apeman-task-contrib-mkdir/blob/master/LICENSE
[my_codeclimate_url]: http://codeclimate.com/github/apeman-repo/apeman-task-contrib-mkdir
[my_codeclimate_badge_url]: http://img.shields.io/codeclimate/github/apeman-repo/apeman-task-contrib-mkdir.svg?style=flat
[my_codeclimate_coverage_badge_url]: http://img.shields.io/codeclimate/coverage/github/apeman-repo/apeman-task-contrib-mkdir.svg?style=flat
[my_coverage_url]: http://apeman-repo.github.io/apeman-task-contrib-mkdir/coverage/lcov-report
[my_npm_url]: http://www.npmjs.org/package/apeman-task-contrib-mkdir
[my_npm_budge_url]: http://img.shields.io/npm/v/apeman-task-contrib-mkdir.svg?style=flat

==> apeman-task-contrib-mkdir-1.0.2.tgz: package/README.md <==
apeman-task-contrib-mkdir
======

[![Build Status][my_travis_badge_url]][my_travis_url]
[![Code Climate][my_codeclimate_badge_url]][my_codeclimate_url]
[![Code Coverage][my_coveralls_badge_url]][my_coveralls_url]
[![npm version][my_npm_budge_url]][my_npm_url]

Apeman task contribution plugin to make directories.


Installation
-------

Install module via [npm][npm_url]

```bash
npm install apeman-task-contrib-mkdir --save-dev
```

Usage
-------

```javascript
/**
 * This is example Apemanfile to use "apeman-task-contrib-mkdir".
 */

"use strict";

module.exports = {
    $package: {/*...*/},
    $tasks: {
        "structure-my-project": {
            "$worker": "apeman-task-contrib-mkdir",
            // Directory names to generate.
            "$options": [
                "bin",
                "lib",
                "docs",
                "docs/apiguide",
                "test",
                "test/unit_tests"
            ]
        }
    }
};
````

Then, run it from call the task via [apeman CLI][apeman_cli_doc_url].

```bash
apeman task apeman-task-contrib-mkdir
```

License
-------

This software is released under the [MIT License][my_license_url].


Links
-------

+ [coz][coz_url]
+ [apeman][apeman_url]

<!-- Links -->
[npm_url]: https://www.npmjs.com/
[apeman_url]: https://github.com/apeman-repo/apeman
<!-- FIXME -->
[apeman_cli_doc_url]: https://github.com/apeman-repo/apeman
[my_repo_url]: https://github.com/apeman-repo/apeman-task-contrib-mkdir
[my_travis_url]: http://travis-ci.org/apeman-repo/apeman-task-contrib-mkdir
[my_travis_badge_url]: http://img.shields.io/travis/apeman-repo/apeman-task-contrib-mkdir.svg?style=flat
[my_license_url]: https://github.com/apeman-repo/apeman-task-contrib-mkdir/blob/master/LICENSE
[my_codeclimate_url]: http://codeclimate.com/github/apeman-repo/apeman-task-contrib-mkdir
[my_codeclimate_badge_url]: http://img.shields.io/codeclimate/github/apeman-repo/apeman-task-contrib-mkdir.svg?style=flat
[my_coveralls_url]: https://coveralls.io/github/apeman-repo/apeman-task-contrib-mkdir
[my_coveralls_badge_url]: http://img.shields.io/coveralls/apeman-repo/apeman-task-contrib-mkdir.svg?style=flat
[my_npm_url]: http://www.npmjs.org/package/apeman-task-contrib-mkdir
[my_npm_budge_url]: http://img.shields.io/npm/v/apeman-task-contrib-mkdir.svg?style=flat
[my_npm_url]: http://www.npmjs.org/package/apeman-task-contrib-mkdir
[my_npm_budge_url]: http://img.shields.io/npm/v/apeman-task-contrib-mkdir.svg?style=flat
[coz_url]: http://okunishinishi.github.io/node-coz/apiguide
